@@ -14,9 +14,10 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+import os
 from optparse import make_option
 from django.conf import settings
-from django.core.management.base import NoArgsCommand
+from django.core.management.base import BaseCommand
 from django.test.utils import setup_test_environment
 from django.test.utils import teardown_test_environment
 
@@ -26,25 +27,31 @@ from lettuce import registry
 from lettuce.django import server
 from lettuce.django import harvest_lettuces
 
-class Command(NoArgsCommand):
-    help = u'Run lettuce tests within each django app'
+class Command(BaseCommand):
+    help = u'Run lettuce tests all along installed apps'
+    requires_model_validation = False
 
-    option_list = NoArgsCommand.option_list[1:] + (
+    option_list = BaseCommand.option_list[1:] + (
         make_option('-v', '--verbosity', action='store', dest='verbosity', default='4',
             type='choice', choices=['0', '3', '4'],
             help='Verbosity level; 0=no output, 3=colorless output, 4=normal output (colorful)'),
+
         make_option('-a', '--apps', action='store', dest='apps', default='',
             help='Run ONLY the django apps that are listed here. Comma separated'),
+
         make_option('-A', '--avoid-apps', action='store', dest='avoid_apps', default='',
             help='AVOID running the django apps that are listed here. Comma separated'),
+
         make_option('-S', '--no-server', action='store_true', dest='no_server', default=False,
             help="will not run django's builtin HTTP server"),
 
+        make_option('-s', '--scenarios', action='store', dest='scenarios', default=None,
+            help='Comma separated list of scenarios to run'),
     )
     def stopserver(self, failed=False):
         raise SystemExit(int(failed))
 
-    def handle_noargs(self, **options):
+    def handle(self, *args, **options):
         settings.DEBUG = False
         setup_test_environment()
 
@@ -59,9 +66,15 @@ class Command(NoArgsCommand):
 
         failed = False
         try:
-            for path in harvest_lettuces(apps_to_run, apps_to_avoid):
+            if args and all(map(os.path.exists, args)):
+                paths = args
+
+            else:
+                paths = harvest_lettuces(apps_to_run, apps_to_avoid)
+
+            for path in paths:
                 registry.clear()
-                result = Runner(path, verbosity).run()
+                result = Runner(path, options.get('scenarios'), verbosity).run()
 
                 if not result or result.steps != result.steps_passed:
                     failed = True
